pub struct GetSessionFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetSession.
Gets the full details of a previously created session, including the session status and configuration.
Implementations
Sourceimpl GetSessionFluentBuilder
impl GetSessionFluentBuilder
Sourcepub fn as_input(&self) -> &GetSessionInputBuilder
pub fn as_input(&self) -> &GetSessionInputBuilder
Access the GetSession as a reference.
Sourcepub async fn send(
self,
) -> Result<GetSessionOutput, SdkError<GetSessionError, HttpResponse>>
pub async fn send( self, ) -> Result<GetSessionOutput, SdkError<GetSessionError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetSessionOutput, GetSessionError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetSessionOutput, GetSessionError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session ID.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session ID.