#[non_exhaustive]pub struct GetSessionOutputBuilder { /* private fields */ }Expand description
A builder for GetSessionOutput.
Implementations
Sourceimpl GetSessionOutputBuilder
impl GetSessionOutputBuilder
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session ID.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session ID.
Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The session description.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The session description.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The session description.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The workgroup to which the session belongs.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The workgroup to which the session belongs.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The workgroup to which the session belongs.
Sourcepub fn engine_version(self, input: impl Into<String>) -> Self
pub fn engine_version(self, input: impl Into<String>) -> Self
The engine version used by the session (for example, PySpark engine version 3). You can get a list of engine versions by calling ListEngineVersions.
Sourcepub fn set_engine_version(self, input: Option<String>) -> Self
pub fn set_engine_version(self, input: Option<String>) -> Self
The engine version used by the session (for example, PySpark engine version 3). You can get a list of engine versions by calling ListEngineVersions.
Sourcepub fn get_engine_version(&self) -> &Option<String>
pub fn get_engine_version(&self) -> &Option<String>
The engine version used by the session (for example, PySpark engine version 3). You can get a list of engine versions by calling ListEngineVersions.
Sourcepub fn engine_configuration(self, input: EngineConfiguration) -> Self
pub fn engine_configuration(self, input: EngineConfiguration) -> Self
Contains engine configuration information like DPU usage.
Sourcepub fn set_engine_configuration(
self,
input: Option<EngineConfiguration>,
) -> Self
pub fn set_engine_configuration( self, input: Option<EngineConfiguration>, ) -> Self
Contains engine configuration information like DPU usage.
Sourcepub fn get_engine_configuration(&self) -> &Option<EngineConfiguration>
pub fn get_engine_configuration(&self) -> &Option<EngineConfiguration>
Contains engine configuration information like DPU usage.
Sourcepub fn notebook_version(self, input: impl Into<String>) -> Self
pub fn notebook_version(self, input: impl Into<String>) -> Self
The notebook version.
Sourcepub fn set_notebook_version(self, input: Option<String>) -> Self
pub fn set_notebook_version(self, input: Option<String>) -> Self
The notebook version.
Sourcepub fn get_notebook_version(&self) -> &Option<String>
pub fn get_notebook_version(&self) -> &Option<String>
The notebook version.
Sourcepub fn monitoring_configuration(self, input: MonitoringConfiguration) -> Self
pub fn monitoring_configuration(self, input: MonitoringConfiguration) -> Self
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn set_monitoring_configuration(
self,
input: Option<MonitoringConfiguration>,
) -> Self
pub fn set_monitoring_configuration( self, input: Option<MonitoringConfiguration>, ) -> Self
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn get_monitoring_configuration(&self) -> &Option<MonitoringConfiguration>
pub fn get_monitoring_configuration(&self) -> &Option<MonitoringConfiguration>
Contains the configuration settings for managed log persistence, delivering logs to Amazon S3 buckets, Amazon CloudWatch log groups etc.
Sourcepub fn session_configuration(self, input: SessionConfiguration) -> Self
pub fn session_configuration(self, input: SessionConfiguration) -> Self
Contains the workgroup configuration information used by the session.
Sourcepub fn set_session_configuration(
self,
input: Option<SessionConfiguration>,
) -> Self
pub fn set_session_configuration( self, input: Option<SessionConfiguration>, ) -> Self
Contains the workgroup configuration information used by the session.
Sourcepub fn get_session_configuration(&self) -> &Option<SessionConfiguration>
pub fn get_session_configuration(&self) -> &Option<SessionConfiguration>
Contains the workgroup configuration information used by the session.
Sourcepub fn status(self, input: SessionStatus) -> Self
pub fn status(self, input: SessionStatus) -> Self
Contains information about the status of the session.
Sourcepub fn set_status(self, input: Option<SessionStatus>) -> Self
pub fn set_status(self, input: Option<SessionStatus>) -> Self
Contains information about the status of the session.
Sourcepub fn get_status(&self) -> &Option<SessionStatus>
pub fn get_status(&self) -> &Option<SessionStatus>
Contains information about the status of the session.
Sourcepub fn statistics(self, input: SessionStatistics) -> Self
pub fn statistics(self, input: SessionStatistics) -> Self
Contains the DPU execution time.
Sourcepub fn set_statistics(self, input: Option<SessionStatistics>) -> Self
pub fn set_statistics(self, input: Option<SessionStatistics>) -> Self
Contains the DPU execution time.
Sourcepub fn get_statistics(&self) -> &Option<SessionStatistics>
pub fn get_statistics(&self) -> &Option<SessionStatistics>
Contains the DPU execution time.
Sourcepub fn build(self) -> GetSessionOutput
pub fn build(self) -> GetSessionOutput
Consumes the builder and constructs a GetSessionOutput.